==> fastrack-utilities-v0.1.0-3b63a4.tar: src/SubmitController.php <==
<?php


namespace Fastrack\Utilities;


use GuzzleHttp\Client;
use SilverStripe\Control\Controller;
use SilverStripe\Control\Email\Email;
use SilverStripe\Control\Session;
use SilverStripe\Core\Environment;
use SilverStripe\ORM\ArrayList;
use SilverStripe\SiteConfig\SiteConfig;
use SilverStripe\View\ArrayData;
use \PageController;

class SubmitController extends PageController
{
	/**
	 * @var array
	 * @config
	 */
	private static $excluded_enquiry_fields = ['to', 'g-recaptcha-response'];

	/**
	 * @var string
	 * @config
	 */
	private static $confirmation_page_title = 'Enquiry sent';

	/**
	 * @var string
	 * @config
	 */
	private static $confirmation_page_content = '<p>Your enquiry has been sent</p>';

	private static $allowed_actions = [
		'enquiry',
		'enquiryConfirmation',
	];

	private static $url_handlers = [
		'enquiry/confirmation' => 'enquiryConfirmation',
		'enquiry' => 'enquiry',
	];

	public function enquiry()
	{
		if (GoogleReCaptcha::validate($this->getRequest()->postVar('g-recaptcha-response'))) {
			$email = new Email();
			$email->setHTMLTemplate('Fastrack\\Utilities\\ContactEmail');
			$email->setData($this->getEnquiryData());
			$email->setSubject('Enquiry from website');
			$email->setTo(explode(',', $this->request->postVar('to')));
			$email->setReplyTo($this->getFromEmail());
			$email->send();
			$this->request->getSession()->set('enquirySent', true);
			$this->logMail($email);
			return $this->redirect('/submit/enquiry/confirmation');
		} else {
			FlashMessage::write($this->request, 'Invalid request, check reCAPTCHA validation', true);
			return $this->returnBack();
		}
	}

	public function enquiryConfirmation()
	{
		if ($this->request->getSession()->get('enquirySent')) {
			$page = \Page::get()->first();
			$data = $page ? $page : new ArrayData([]);
			$data->setField('Title', $this->config()->get('confirmation_page_title'));
			$data->setField('Content', $this->config()->get('confirmation_page_content'));
			$this->request->getSession()->set('enquirySent', false);
			return $this->customise($data)->renderWith(['Page', 'Page']);
		} else {
			return $this->redirect('/');
		}
	}

	private function getEnquiryData()
	{
		$data = new ArrayList([]);
		$excludedFields = $this->config()->get('excluded_enquiry_fields');
		foreach ($this->request->postVars() as $field => $value) {
			if (!in_array($field, $excludedFields)) {
				$data->add(new ArrayData(['Field' => $field, 'Value' => $value]));
			}
		}
		return new ArrayData(['Fields' => $data]);
	}

	private function returnBack()
	{
		$response = parent::redirectBack();
		$response->addHeader('Location', $response->getHeader('Location') . '#form-validation-message');
		return $response;
	}

	private function logMail(Email $email)
	{
		$mail = Mail::create();
		$mail->To = $this->request->postVar('to');
		$mail->From = $this->getFromEmail();
		$mail->Body = $email->getBody();
		$mail->write();
	}

	private function getFromEmail()
	{
		return $this->request->postVar('email') ?: $this->request->postVar('from');
	}
}

==> fastrack-utilities-v1.1.20-072693.tar: src/SubmitController.php <==
<?php


namespace Fastrack\Utilities;


use GuzzleHttp\Client;
use SilverStripe\Control\Controller;
use SilverStripe\Control\Email\Email;
use SilverStripe\Control\HTTPResponse;
use SilverStripe\Control\Session;
use SilverStripe\Core\Environment;
use SilverStripe\ORM\ArrayList;
use SilverStripe\SiteConfig\SiteConfig;
use SilverStripe\View\ArrayData;
use \PageController;

class SubmitController extends PageController
{
	/**
	 * @var array
	 * @config
	 */
	private static $excluded_enquiry_fields = ['to', 'g-recaptcha-response'];

	/**
	 * @var string
	 * @config
	 */
	private static $confirmation_page_title = 'Enquiry sent';

	/**
	 * @var string
	 * @config
	 */
	private static $confirmation_page_content = '<p>Your enquiry has been sent</p>';

	private static $allowed_actions = [
		'enquiry',
		'enquiryConfirmation',
	];

	private static $url_handlers = [
		'enquiry/confirmation' => 'enquiryConfirmation',
		'enquiry' => 'enquiry',
	];

	public function enquiry()
	{
		if (GoogleReCaptcha::validate($this->getRequest()->postVar('g-recaptcha-response'))) {
			$email = new Email();
			$email->setHTMLTemplate('Fastrack\\Utilities\\ContactEmail');
			$email->setData($this->getEnquiryData());
			$email->setSubject('Enquiry from website');
			$email->setTo(explode(',', $this->request->postVar('to')));
			$email->setReplyTo($this->getFromEmail());
			$email->send();
			$this->request->getSession()->set('enquirySent', true);
			$this->logMail($email);
			return $this->createResponse(true, 'Success');
		} else {
			$flashMessage = 'Invalid request, check reCAPTCHA validation';
			FlashMessage::write($this->request, $flashMessage, true);
			return $this->createResponse(false, $flashMessage);
		}
	}

	public function enquiryConfirmation()
	{
		if ($this->request->getSession()->get('enquirySent')) {
			$page = \Page::get()->first();
			$data = $page ? $page : new ArrayData([]);
			$data->setField('Title', $this->config()->get('confirmation_page_title'));
			$data->setField('Content', $this->config()->get('confirmation_page_content'));
			$this->request->getSession()->set('enquirySent', false);
			return $this->customise($data)->renderWith(['Page', 'Page']);
		} else {
			return $this->redirect('/');
		}
	}

	private function getEnquiryData()
	{
		$data = new ArrayList([]);
		$excludedFields = $this->config()->get('excluded_enquiry_fields');
		foreach ($this->request->postVars() as $field => $value) {
			if (!in_array($field, $excludedFields)) {
				$data->add(new ArrayData(['Field' => $field, 'Value' => $value]));
			}
		}
		return new ArrayData(['Fields' => $data]);
	}

	private function returnBack()
	{
		$response = parent::redirectBack();
		$response->addHeader('Location', $response->getHeader('Location') . '#form-validation-message');
		return $response;
	}

	private function logMail(Email $email)
	{
		$mail = Mail::create();
		$mail->To = $this->request->postVar('to');
		$mail->From = $this->getFromEmail();
		$mail->Body = $email->getBody();
		$mail->write();
	}

	private function getFromEmail()
	{
		return $this->request->postVar('email') ?: $this->request->postVar('from');
	}

	/**
	 * @param bool $success
	 * @param string $message
	 * @return HTTPResponse
	 */
	private function createResponse(bool $success, string $message): HTTPResponse
	{
		if ($this->request->isAjax()) {
			return $this->getResponse()
				->setStatusCode($success ? 200 : 400)
				->setBody(json_encode(['message' => $message]))
				->addHeader('Content-type', 'application/json');
		} else {
			return $success ? $this->redirect('/submit/enquiry/confirmation') : $this->returnBack();
		}
	}

}
